@@ -1,26 +1,40 @@
+/**
+ * Copyright 2017 Red Hat Inc.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License"); you may
+ * not use this file except in compliance with the License. You may obtain
+ * a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+ * License for the specific language governing permissions and limitations
+ * under the License.
+ */
+
 import { getAuthTokenId, getServiceUrl } from '../../js/services/utils';
 import { InitialLoginState } from '../../js/immutableRecords/login';
 import { List, Map } from 'immutable';
-import matchers from 'jasmine-immutable-matchers';
 import store from '../../js/store';
 
 describe('utility functions', () => {
   const appState = {
     login: new InitialLoginState({
-      keystoneAccess: Map({
-        token: Map({
-          id: 123456,
-          tenant: Map({
-            id: 778899
-          })
+      token: Map({
+        id: 123456,
+        project: Map({
+          id: 778899
         }),
-        serviceCatalog: List([
+        catalog: List([
           Map({
             name: 'nova',
             endpoints: List([
               Map({
-                adminURL: 'http://someNovaAdminUrl',
-                publicURL: 'http://someNovaPublicUrl'
+                id: '1',
+                interface: 'public',
+                url: 'http://someNovaPublicUrl'
               })
             ])
           }),
@@ -28,7 +42,9 @@ describe('utility functions', () => {
             name: 'fooservice',
             endpoints: List([
               Map({
-                publicURL: 'http://IGNOREDFooPublicUrl'
+                id: '1',
+                interface: 'public',
+                url: 'http://someNovaPublicUrl'
               })
             ])
           }),
@@ -36,7 +52,9 @@ describe('utility functions', () => {
             name: 'macroservice',
             endpoints: List([
               Map({
-                publicURL: 'http://MacroPublicUrl/v1/Foo_%(tenant_id)s'
+                id: '1',
+                interface: 'public',
+                url: 'http://MacroPublicUrl/v1/Foo_%(project_id)s'
               })
             ])
           })
@@ -51,7 +69,6 @@ describe('utility functions', () => {
   };
 
   beforeEach(() => {
-    jasmine.addMatchers(matchers);
     spyOn(store, 'getState').and.returnValue(appState);
   });
 
@@ -65,13 +82,15 @@ describe('utility functions', () => {
     });
 
     it('gives precedence to urls made available through app.conf', () => {
-      expect(getServiceUrl(
-        'fooservice', null, { fooservice: 'http://FooPublicURL' })
+      expect(
+        getServiceUrl('fooservice', null, { fooservice: 'http://FooPublicURL' })
       ).toEqual('http://FooPublicURL');
     });
 
-    it('expands urls containing the keystone tenant macro', () => {
-      expect(getServiceUrl('macroservice')).toEqual('http://MacroPublicUrl/v1/Foo_778899');
+    it('expands urls containing the keystone project macro', () => {
+      expect(getServiceUrl('macroservice')).toEqual(
+        'http://MacroPublicUrl/v1/Foo_778899'
+      );
     });
   });
 
