@@ -69,6 +69,7 @@ class Nodes extends React.Component {
       ? <NodesTableView />
       : <NodesListForm>
           <NodesListView
+            fetchNodeIntrospectionData={this.props.fetchNodeIntrospectionData}
             nodes={this.props.nodes}
             nodesInProgress={this.props.nodesInProgress}
           />
@@ -118,6 +119,7 @@ class Nodes extends React.Component {
 Nodes.propTypes = {
   contentView: PropTypes.string.isRequired,
   currentPlanName: PropTypes.string.isRequired,
+  fetchNodeIntrospectionData: PropTypes.func.isRequired,
   fetchNodes: PropTypes.func.isRequired,
   fetchRoles: PropTypes.func.isRequired,
   fetchingNodes: PropTypes.bool.isRequired,
@@ -141,6 +143,8 @@ const mapStateToProps = state => ({
 
 const mapDispatchToProps = dispatch => ({
   fetchNodes: () => dispatch(NodesActions.fetchNodes()),
+  fetchNodeIntrospectionData: nodeId =>
+    dispatch(NodesActions.fetchNodeIntrospectionData(nodeId)),
   fetchRoles: currentPlanName =>
     dispatch(RolesActions.fetchRoles(currentPlanName))
 });
