@@ -1,7 +1,24 @@
+/**
+ * Copyright 2017 Red Hat Inc.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License"); you may
+ * not use this file except in compliance with the License. You may obtain
+ * a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+ * License for the specific language governing permissions and limitations
+ * under the License.
+ */
+
 import ClassNames from 'classnames';
 import { defineMessages, FormattedMessage } from 'react-intl';
 import React from 'react';
 import PropTypes from 'prop-types';
+import ImmutablePropTypes from 'react-immutable-proptypes';
 
 import {
   ListViewAdditionalInfo,
@@ -61,7 +78,7 @@ export default class NodeListItem extends React.Component {
   }
 
   render() {
-    const { node, inProgress } = this.props;
+    const { fetchNodeIntrospectionData, node, inProgress } = this.props;
 
     const iconClass = ClassNames({
       'pficon pficon-server': true,
@@ -73,7 +90,7 @@ export default class NodeListItem extends React.Component {
           <ListViewExpand expanded={this.state.expanded} />
           <ListViewCheckbox
             disabled={inProgress}
-            name={`values.${node.uuid}`}
+            name={`values.${node.get('uuid')}`}
           />
           <ListViewMainInfo>
             <ListViewLeft>
@@ -82,23 +99,25 @@ export default class NodeListItem extends React.Component {
             <ListViewBody>
               <ListViewDescription>
                 <ListViewDescriptionHeading>
-                  {node.name || node.uuid}
+                  {node.get('name') || node.get('uuid')}
                 </ListViewDescriptionHeading>
                 <ListViewDescriptionText>
                   <NodePowerState
-                    powerState={node.power_state}
-                    targetPowerState={node.target_power_state}
+                    powerState={node.get('power_state')}
+                    targetPowerState={node.get('target_power_state')}
                   />
                   <NodeMaintenanceState
-                    maintenance={node.maintenance}
-                    reason={node.maintenance_reason}
+                    maintenance={node.get('maintenance')}
+                    reason={node.get('maintenance_reason')}
                   />
                   {' | '}
-                  <NodeIntrospectionStatus status={node.introspectionStatus} />
+                  <NodeIntrospectionStatus
+                    status={node.get('introspectionStatus').toJS()}
+                  />
                   {' | '}
                   <NodeProvisionState
-                    provisionState={node.provision_state}
-                    targetProvisionState={node.target_provision_state}
+                    provisionState={node.get('provision_state')}
+                    targetProvisionState={node.get('target_provision_state')}
                   />
                 </ListViewDescriptionText>
               </ListViewDescription>
@@ -107,27 +126,30 @@ export default class NodeListItem extends React.Component {
                   <span className="pficon pficon-flavor" />
                   <FormattedMessage {...messages.profile} />
                   &nbsp;
-                  {parseNodeCapabilities(node.properties.capabilities)
-                    .profile || '-'}
+                  {parseNodeCapabilities(
+                    node.getIn(['properties', 'capabilities'])
+                  ).profile || '-'}
                 </ListViewAdditionalInfoItem>
                 <ListViewAdditionalInfoItem>
                   <span className="pficon pficon-cpu" />
-                  <strong>{node.properties.cpus || '-'}</strong>
+                  <strong>{node.getIn(['properties', 'cpus'], '-')}</strong>
                   &nbsp;
                   <FormattedMessage
                     {...messages.cpuCores}
-                    values={{ cpuCores: node.properties.cpus }}
+                    values={{ cpuCores: node.getIn(['properties', 'cpus']) }}
                   />
                 </ListViewAdditionalInfoItem>
                 <ListViewAdditionalInfoItem>
                   <span className="pficon pficon-memory" />
-                  <strong>{node.properties.memory_mb || '-'}</strong>
+                  <strong>
+                    {node.getIn(['properties', 'memory_mb'], '-')}
+                  </strong>
                   &nbsp;
                   <FormattedMessage {...messages.ram} />
                 </ListViewAdditionalInfoItem>
                 <ListViewAdditionalInfoItem>
                   <span className="fa fa-database" />
-                  <strong>{node.properties.local_gb || '-'}</strong>
+                  <strong>{node.getIn(['properties', 'local_gb'], '-')}</strong>
                   &nbsp;
                   <FormattedMessage {...messages.disk} />
                 </ListViewAdditionalInfoItem>
@@ -139,13 +161,17 @@ export default class NodeListItem extends React.Component {
           onClose={this.toggleExpanded.bind(this)}
           expanded={this.state.expanded}
         >
-          <NodeExtendedInfo node={node} />
+          <NodeExtendedInfo
+            node={node}
+            fetchNodeIntrospectionData={fetchNodeIntrospectionData}
+          />
         </ListViewItemContainer>
       </ListViewItem>
     );
   }
 }
 NodeListItem.propTypes = {
+  fetchNodeIntrospectionData: PropTypes.func.isRequired,
   inProgress: PropTypes.bool.isRequired,
-  node: PropTypes.object.isRequired
+  node: ImmutablePropTypes.map.isRequired
 };
